==> ul_db_utils-3.3.0-py3-none-any.whl: ul_db_utils/repository/sqlalchemy_repository.py <==
from abc import ABC
from typing import Optional, List, Dict, Any, Tuple
from uuid import UUID

from sqlalchemy.orm import Session, Query
from ul_db_utils.model.base_model import BaseModel
from ul_db_utils.modules.postgres_modules.db import db, DbModel

from ul_db_utils.repository.abstract_repository import Repository
from ul_db_utils.search.db_search import db_search
from ul_db_utils.utils.ensure_db_object_exists import ensure_db_object_exists


class SQLAlchemyRepository(Repository, ABC):
    model: DbModel
    session: Session = db.session

    @classmethod
    def get_all(    # type: ignore
        cls,
        limit: int,
        offset: int,
        filters: Optional[List[Dict[str, Any]]],
        sorts: Optional[List[Tuple[str, str]]],
        initial_query: 'Optional[Query[BaseModel]]' = None,
    ) -> List[BaseModel]:
        object_list = db_search(
            model=cls.model,
            filters=filters,
            sorts=sorts,
            limit=limit,
            offset=offset,
            initial_query=initial_query,
        ).all()
        return object_list

    @classmethod
    def get_total_count(    # type: ignore
        cls,
        filters: Optional[List[Dict[str, Any]]],
        initial_query: 'Optional[Query[BaseModel]]' = None,
    ) -> int:
        list_count = db_search(
            model=cls.model,
            initial_query=initial_query,
            filters=filters,
        ).count()
        return list_count

    @classmethod
    def get_by_id(
        cls,
        id: UUID,
    ) -> BaseModel:
        obj = cls.model.query.filter_by(id=id).first()
        return ensure_db_object_exists(cls.model, obj)

    @classmethod
    def soft_get_by_id(
        cls,
        id: UUID,
    ) -> Optional[BaseModel]:
        return cls.model.query.filter_by(id=id).first()

==> ul_db_utils-3.3.1-py3-none-any.whl: ul_db_utils/repository/sqlalchemy_repository.py <==
from abc import ABC
from typing import Optional, List, Dict, Any, Tuple
from uuid import UUID

from sqlalchemy.orm import Query
from ul_db_utils.model.base_model import BaseModel
from ul_db_utils.modules.postgres_modules.db import DbModel

from ul_db_utils.repository.abstract_repository import Repository
from ul_db_utils.search.db_search import db_search
from ul_db_utils.utils.ensure_db_object_exists import ensure_db_object_exists


class SQLAlchemyRepository(Repository, ABC):
    model: DbModel

    @classmethod
    def get_all(    # type: ignore
        cls,
        limit: int,
        offset: int,
        filters: Optional[List[Dict[str, Any]]],
        sorts: Optional[List[Tuple[str, str]]],
        initial_query: 'Optional[Query[BaseModel]]' = None,
    ) -> List[BaseModel]:
        object_list = db_search(
            model=cls.model,
            filters=filters,
            sorts=sorts,
            limit=limit,
            offset=offset,
            initial_query=initial_query,
        ).all()
        return object_list

    @classmethod
    def get_total_count(    # type: ignore
        cls,
        filters: Optional[List[Dict[str, Any]]],
        initial_query: 'Optional[Query[BaseModel]]' = None,
    ) -> int:
        list_count = db_search(
            model=cls.model,
            initial_query=initial_query,
            filters=filters,
        ).count()
        return list_count

    @classmethod
    def get_by_id(
        cls,
        id: UUID,
    ) -> BaseModel:
        obj = cls.model.query.filter_by(id=id).first()
        return ensure_db_object_exists(cls.model, obj)

    @classmethod
    def soft_get_by_id(
        cls,
        id: UUID,
    ) -> Optional[BaseModel]:
        return cls.model.query.filter_by(id=id).first()
